Ensures the records class (and its attributes) is only retained when
the columns they point to are still present after subsetting. This covers
base R subsetting (x[...]), which does not go through dplyr's
dplyr_reconstruct machinery.
# S3 method for records
[(x, i, j, ..., drop)an object used to select a method
row index
column index
further arguments passed to or from other methods
logical, whether to simplify to a vector when selecting a single column