dplyr_reconstruct.records: Wrapper to discard class in dplyr

View source: R/aaa_classes.r

dplyr_reconstruct.recordsR Documentation

Wrapper to discard class in dplyr

Description

This function is called internally by dplyr. It prevents the propagation of attributes dependent on columns when such columns are filtered out.

Usage

## S3 method for class 'records'
dplyr_reconstruct(data, template)

Arguments

data

A tibble. We use tibbles because they avoid some inconsistent subset-assignment use cases.

template

Template data frame to use for restoring attributes.


camtrapR documentation built on July 28, 2026, 5:10 p.m.