print.camOp: Printing method for camera trap station operation matrix

View source: R/aaa_classes.r

print.camOpR Documentation

Printing method for camera trap station operation matrix

Description

Printing method for camera trap station operation matrix

Usage

## S3 method for class 'camOp'
print(x, nRows = 4, nCols = 3, digits = 3, ...)

Arguments

x

an object used to select a method

nRows

the number of first and last rows to display

nCols

the number of first and last columns to display

digits

the number of digits to use within cells

...

further arguments passed to or from other methods


camtrapR documentation built on July 28, 2026, 5:10 p.m.