| summary.records | R Documentation |
Summary method for record tables
## S3 method for class 'records'
summary(object, nSpeciesMax = 5, ...)
object |
an object of class |
nSpeciesMax |
integer for the maximum number of species to show in the per-species detection table (defaults = 5) |
... |
further arguments passed to or from other methods |
the species table (returned invisibly and unfiltered)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.