capthist objects for spatial capture-recapture analyses in the secr package. In addition, basic survey statistics are computed. The functions build on one another in a logical sequence.
The only manual input needed it species (and individual) identification, which is achieved by moving images into species directories or by tagging images in image management software. Besides, a table holding basic information about camera trap station IDs, locations and trapping periods must be created in spreadsheet software.
createStationFolders |
| Create camera trap station directories for raw images |
timeShiftImages |
| Apply time shifts to JPEG images |
imageRename |
| Copy and rename images based on station ID and image creation date |
appendSpeciesNames |
| Add or remove species names from image filenames |
| --------------------------- |
| ---------------------------------------------------------------------------------------------- |
checkSpeciesNames |
| Check species names against the ITIS taxonomic database |
createSpeciesFolders |
| Create directories for species identification |
checkSpeciesIdentification |
| Consistency check on species image identification |
getSpeciesImages |
| Gather all images of a species in a new directory |
| --------------------------- |
| ---------------------------------------------------------------------------------------------- |
recordTable |
| Create a species record table from camera trap images |
recordTableIndividual |
| Create a single-species record table from camera trap images with individual IDs |
exifTagNames |
| Return Exif metadata tags and tag names from JPEG images |
exiftoolPath |
| Add the directory containing exiftool.exe to PATH temporarily (Windows only) |
| --------------------------- |
| ---------------------------------------------------------------------------------------------- |
detectionMaps |
| Generate maps of species richness and species presence by station |
activityHistogram |
| Single-species diel activity histograms |
activityDensity |
| Single-species diel activity kernel density estimation plots |
activityRadial |
| Single-species diel activity radial plot |
activityOverlap |
| Two-species diel activity overlap plots and estimates |
| --------------------------- |
| ---------------------------------------------------------------------------------------------- |
cameraOperation |
| Create a camera operability matrix |
detectionHistory |
| Species detection histories for occupancy analyses |
spatialDetectionHistory |
| Detection histories of individuals for spatial capture-recapture analyses |
surveyReport |
| Create a report about camera trap surveys and species detections |
| --------------------------- |
| ---------------------------------------------------------------------------------------------- |
camtraps |
| Sample camera trap station information table |
recordTableSample |
| Sample species record table |
recordTableIndividualSample |
| Single-species record table with individual IDs |
timeShiftTable |
| Sample camera trap time shift information |
| --------------------------- |
| ---------------------------------------------------------------------------------------------- |