camtrapR-package: Overview of the functions in the camtrapR package
Description
This package provides a streamlined workflow for processing data generated in camera trap-based wildlife studies and prepares input for further analyses, particularly in occupancy and spatial capture-recapture frameworks.
It suggests a simple data structure and provides functions for managing digital camera trap photographs, generating record databases, maps of species richness and species detections and species activity diagrams. It further helps prepare subsequent analyses by creating detection/non-detection matrices for occupancy analyses, e.g. in the unmarked package, and capthist objects for spatial capture-recapture analyses in the secr package. In addition, basic survey statistics are computed. The functions build on one another in a logical sequence.
The only manual input needed it species (and individual) identification, which is achieved by moving images into species directories or metadata tagging, and the creation of a table holding basic information about camera trap station IDs, locations and trapping periods.Image organisation and management
The functions in this section set up a directory structure for storing camera trap images and identifying species and individuals from images. They build on one another and can be run in sequential order as needed.
ll{
createStationFolders Create a directory structure for raw images
timeShiftImages Apply time shifts to JPEG image metadata
imageRename Rename images based on camera trap station ID and creation date
createSpeciesFolders Create species directories for species identification
checkSpeciesFolders Consistency check on species image identification
appendSpeciesNames Add or remove species names from image filenames
getSpeciesImages Copy all images of a species to a new directory
--------------------------- ----------------------------------------------------------------------------------------------
}Image data extraction
These function use the directory structure built above (Section 'Image management workflow') and a table containing basic information about camera traps and/or stations (IDs, location, trapping period).
ll{
recordDatabase Create a species record database from camera trap images
exifTagNames Extract Exif metadata tag names from JPEG images
exiftoolPath Add a directory to PATH temporarily (for exiftool.exe under Windows)
--------------------------- ----------------------------------------------------------------------------------------------
}Data exploration and visualisation
These plots are generated from the record database and the camera trap table.
ll{
detectionMaps Generate maps of species richness and species presence by station
activityHistogram Single-species diel activity histograms
activityDensity Single-species diel activity kernel density estimation plots
activityRadial Single-species diel activity radial plot
activityOverlap Two-species diel activity overlap plots and estimates
--------------------------- ----------------------------------------------------------------------------------------------
}Data export
ll{
cameraOperation Create a camera operability matrix
detectionHistory Species detection histories for occupancy analyses
spatialDetectionHistory Generate a capthist object for spatial capture-recapture analyses
surveyReport Create a report about camera trap surveys and species detections
--------------------------- ----------------------------------------------------------------------------------------------
}Sample data
ll{
camtraps Sample camera trap station information table
recordDatabaseSample Sample species record database
recordDatabaseIndividualSample Single-species record database with individual IDs
timeShiftTable Sample camera trap time shift information
--------------------------- ----------------------------------------------------------------------------------------------
}Details
Raw camera trap images are renamed automatically and stored in a directory structure of camera trap station directories. Within each of these camera trap station directories, species are identified from images by moving images into species subdirectories. Alternatively, metadata species tags can be assigned to the images in image management software, e.g. DigiKam or Adobe Bridge. Please note that 1 (non-essential) function in the workflow is not compatible with identification by metadata tagging ( getSpeciesImages).
Image metadata (such as date and time or user-assigned tags) are extracted from the images using Phil Harvey's Exiftool (available from http://www.sno.phy.queensu.ca/~phil/exiftool/) and the information is stored in a record database. An adjustable criterion for temporal independence of records can be applied. Maps of species presence and species richness can be generated. Several functions are available for plotting single- and two-species activity patterns.
Information about the camera-specific trapping periods (and periods of malfunction) are summarized into information about camera trap operability. These, together with the record database, are used to generate species detection histories for occupancy and spatial capture-recapture analyses. The user has considerable freedom in generating the detection histories; sampling occasion length and and occasion start times are adjustable. In addition, trapping effort (i.e. active trap nights per station and occasion) can be computed for use as an observation covariate.References
Lemon, J. (2006) Plotrix: a package in the red light district of R. R-News, 6(4): 8-12.
Mike Meredith and Martin Ridout (2014). overlap: Estimates of coefficient of overlapping for animal activity patterns. R package version 0.2.4. http://CRAN.R-project.org/package=overlap
Phil Harvey's Exiftool http://www.sno.phy.queensu.ca/~phil/exiftool/See Also
overlap
unmarked
secr
plotrix