camtrapR-package: Overview of the functions in the camtrapR package
Description
This package provides a streamlined workflow for the processing and analysis of data generated in camera trap-based wildlife studies.
It suggests a simple data structure and provides functions for managing digital camera trap photographs, generates record databases, maps and detection/non-detection matrices for occupancy analyses, e.g. in the unmarked package. The function build on one another in a logical sequence.
Apart from species identification, which is achieved by moving images into species directories, and the creation of a table holding basic information about camera trap station IDs, locations and trapping periods, no manual input is required.Image management workflow
The functions in this section build on one another and can be run in sequential order as needed.
ll{
exiftoolPath Add directory containing Exiftool to PATH
TimeShiftImages Apply time shifts to image metadata
imageRename Copy and rename images based on station ID, camera ID, date and time
createSpeciesFolders Create directories for species identification
checkSpeciesFolders Check if images were identified correctly
appendSpeciesNames Add or remove species names from images
exifTagNames Extract Exif metadata tag names
recordDatabase Create a species record database from camera trap images
detectionMaps Generate maps of species richness and species presence by station
cameraOperation Compute a camera operability matrix
detectionHistory Generate species detection histories
surveyReport Generate information about trapping periods and species detections
}Additional functions
ll{
getSpeciesImages Fetch and save all images of a species
}Details
Image metadata are extracted using Phil Harvey's Exiftool (available from http://www.sno.phy.queensu.ca/~phil/exiftool/).
From the folder structure thus set up, a record database can be created with an adjustable criterion for temporal independence of records. Maps of species presence and species richness can be generated as well as simple survey statistics.
Several functions are available for plotting single- and two-species activity patterns.
Information about the camera-specific trapping periods are summarized into information about camera trap operability. These together with the record database are used to generate species detection histories. The user has considerable freedom in generating the detection histories; format, session lengths, and session start times are adjustable.References
Lemon, J. (2006) Plotrix: a package in the red light district of R. R-News, 6(4): 8-12.
Mike Meredith and Martin Ridout (2014). overlap: Estimates of coefficient of overlapping for animal activity patterns. R package version 0.2.4. http://CRAN.R-project.org/package=overlap
Phil Harvey's Exiftool http://www.sno.phy.queensu.ca/~phil/exiftool/