| dplyr_reconstruct.records | R Documentation |
This function is called internally by dplyr. It prevents the propagation of attributes dependent on columns when such columns are filtered out.
## S3 method for class 'records'
dplyr_reconstruct(data, template)
data |
A tibble. We use tibbles because they avoid some inconsistent subset-assignment use cases. |
template |
Template data frame to use for restoring attributes. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.