Learn R Programming

camtrapR (version 3.1.0)

dplyr_reconstruct.records: Wrapper to discard class in dplyr

Description

This function is called internally by dplyr. It prevents the propagation of attributes dependent on columns when such columns are filtered out.

Usage

# S3 method for records
dplyr_reconstruct(data, template)

Arguments

data

A tibble. We use tibbles because they avoid some inconsistent subset-assignment use cases.

template

Template data frame to use for restoring attributes.