This function is called internally by dplyr. It prevents the propagation of attributes dependent on columns when such columns are filtered out.
# S3 method for records
dplyr_reconstruct(data, template)A tibble. We use tibbles because they avoid some inconsistent subset-assignment use cases.
Template data frame to use for restoring attributes.