| print.camOp | R Documentation |
Printing method for camera trap station operation matrix
## S3 method for class 'camOp'
print(x, nRows = 4, nCols = 3, digits = 3, ...)
x |
an object used to select a method |
nRows |
the number of first and last rows to display |
nCols |
the number of first and last columns to display |
digits |
the number of digits to use within cells |
... |
further arguments passed to or from other methods |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.