Printing method for camera trap station operation matrix
# S3 method for camOp
print(x, nRows = 4, nCols = 3, digits = 3, ...)an object used to select a method
the number of first and last rows to display
the number of first and last columns to display
the number of digits to use within cells
further arguments passed to or from other methods