print.detHist: Printing method for detection history
Description
Printing method for detection history
Usage
# S3 method for detHist
print(x, nRows = 4, nCols = 3, digits = 3, ...)
Arguments
- x
an object used to select a method
- nRows
the number of first and last rows to display
- nCols
the number of first and last columns to display
- digits
the number of digits to use within cells
- ...
further arguments passed to or from other methods