View source: R/readWildlifeInsights.R
| readWildlifeInsights | R Documentation |
This function imports camera trap data from Wildlife Insights into a format compatible with camtrapR. It can read data from a directory containing CSV files, from a ZIP file, or from individual CSV files.
readWildlifeInsights(
directory = NULL,
zipfile = NULL,
deployment_file = NULL,
image_file = NULL
)
directory |
character. Path to folder containing CSV files exported from Wildlife Insights. |
zipfile |
character. Path to a ZIP file exported from Wildlife Insights. |
deployment_file |
character. Path to the deployments CSV file. |
image_file |
character. Path to the images CSV file. |
A list containing three elements:
CTtable: The full camera trap table, based on deployments.csv
CTtable_aggregated: An aggregated version of the camera trap table, with one row per station
recordTable: The record table, based on images.csv with additional columns from deployments.csv
## Not run:
# Reading from a directory
wi_data <- readWildlifeInsights(directory = "path/to/csv_files")
# Reading from a ZIP file
wi_data <- readWildlifeInsights(zipfile = "path/to/wildlife_insights_export.zip")
# Reading from separate CSV files
wi_data <- readWildlifeInsights(deployment_file = "path/to/deployments.csv",
image_file = "path/to/images.csv")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.