| [.detHist | R Documentation |
Ensures that subsetting a detHist object (e.g. x[1],
x["detection_history"]) retains the detHist class and its
attributes, so the result still prints via print.detHist
instead of falling back to the default list print.
## S3 method for class 'detHist'
x[i, ...]
x |
an object of class |
i |
index specifying elements to extract |
... |
further arguments passed to or from other methods |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.